==> igniteui-react-charts-18.7.0-beta.2.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.yt = new ScatterFrame();
        _this.yv = new ScatterFrame();
        _this.yr = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.bi = function () {
        return new ScatterSeries();
    };
    ScatterSeries.prototype.get_eg = function () {
        return true;
    };
    ScatterSeries.prototype.cq = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.jj = function () {
        return 0.7;
    };
    ScatterSeries.prototype.ws = function () {
        if (this.wr == 0) {
            return 2;
        }
        return _super.prototype.ws.call(this);
    };
    ScatterSeries.prototype.qw = function (a) {
        _super.prototype.qw.call(this, a);
        this.acd = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dk = null;
        _this.dk = a;
        return _this;
    }
    ScatterSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.w1 = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.vu = a;
        this.e.jk = 3;
        this.e.jl = 2;
        this.e.jm = 2;
        this.e.ha = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };

==> igniteui-react-charts-18.7.5-beta.2.tgz: package/esm5/lib/ScatterSeries_combined.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { ScatterBase } from "./ScatterBase";
import { markType } from "igniteui-react-core";
import { ScatterFrame } from "./ScatterFrame";
import { ScatterBaseView } from "./ScatterBaseView";
import { Defaults } from "./Defaults";
import { Color } from "igniteui-react-core";
/**
 * @hidden
 */
var ScatterSeries = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeries, _super);
    function ScatterSeries() {
        var _this = _super.call(this) || this;
        _this.ab = ScatterSeries.$;
        _this.y2 = new ScatterFrame();
        _this.y4 = new ScatterFrame();
        _this.y0 = new ScatterFrame();
        return _this;
    }
    ScatterSeries.prototype.bj = function () {
        return new ScatterSeries();
    };
    ScatterSeries.prototype.get_ei = function () {
        return true;
    };
    ScatterSeries.prototype.cs = function () {
        return new ScatterSeriesView(this);
    };
    ScatterSeries.prototype.jl = function () {
        return 0.7;
    };
    ScatterSeries.prototype.w1 = function () {
        if (this.w0 == 0) {
            return 2;
        }
        return _super.prototype.w1.call(this);
    };
    ScatterSeries.prototype.q1 = function (a) {
        _super.prototype.q1.call(this, a);
        this.acn = a;
    };
    ScatterSeries.$t = markType(ScatterSeries, 'ScatterSeries', ScatterBase.$);
    return ScatterSeries;
}(ScatterBase));
export { ScatterSeries };
/**
 * @hidden
 */
var ScatterSeriesView = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ScatterSeriesView, _super);
    function ScatterSeriesView(a) {
        var _this = _super.call(this, a) || this;
        _this.dk = null;
        _this.dk = a;
        return _this;
    }
    ScatterSeriesView.prototype.au = function () {
        _super.prototype.au.call(this);
        if (!this.q) {
            this.b4.xa = Defaults.e;
        }
    };
    ScatterSeriesView.prototype.af = function () {
        var a = new Color();
        a.colorString = "rgba(95,95,95,0.5)";
        this.e.v1 = a;
        this.e.jm = 3;
        this.e.jn = 2;
        this.e.jo = 2;
        this.e.hc = false;
    };
    ScatterSeriesView.$t = markType(ScatterSeriesView, 'ScatterSeriesView', ScatterBaseView.$);
    return ScatterSeriesView;
}(ScatterBaseView));
export { ScatterSeriesView };
